# Changelog

## [stormi-v0.2.8](https://github.com/pinellolab/stormi/compare/stormi-v0.2.7...stormi-v0.2.8) (2025-04-16)

### Bug Fixes

* **preprocessing:** use correct version of compute_motif_scores ([f44dd36](https://github.com/pinellolab/stormi/commit/f44dd368063252e6e43d3daaa7eed5e56ca9f58f))
* **test_motifs:** refactor to correctly apply to updated _motifs module ([3fbfae2](https://github.com/pinellolab/stormi/commit/3fbfae27089adcf5363c7b03606e6a4265a4431a))
